==> dcg_service-1.0.5.tar.gz: dcg_service-1.0.5/src/dcg_service/core/exceptions.py <==
"""
Contains override Exception class.
"""
from flask import jsonify
from flask_babel import lazy_gettext as _
from . import app, utils
from .constants import STATUS_CODE_MESSAGE
from .logger import logger
from .response import CustomResponse


class ExceptionBase(Exception):
    """
    Base exception handler
    """
    code = 500
    default_detail = _(STATUS_CODE_MESSAGE.get(code))
    error_field = 'message'

    def __init__(self, detail=None, status_code=None, raise_default=False, error_field=error_field):
        self.detail = detail or self.default_detail
        self.error_field = error_field
        if raise_default:
            self.detail = detail or self.default_detail
        self.messages = [self.detail] if isinstance(self.detail, (str, bytes)) else self.detail
        self.status_code = status_code or self.code
        super(ExceptionBase, self).__init__(detail)

    def __str__(self):
        """
        Return exception str error.
        """
        return str(self.detail)

    def get_exception_message(self, args: Exception.args):
        """
        Return Exception messages as dict.
        :param args: `Exception.args`
        :return: dict
        """
        all_exception_detail = dict()
        if isinstance(args, tuple):
            for arg in args:
                if getattr(arg, 'args', None):
                    all_exception_detail.update(self.get_exception_message(arg.args))
                elif isinstance(arg, dict):
                    all_exception_detail.update(arg)
                else:
                    all_exception_detail.update({self.error_field: str(arg) if arg else str(self.detail)})
        return all_exception_detail

    @property
    def messages_dict(self):
        """
        Return `exceptions` of type Dict.
        """
        exception_detail = self.get_exception_message(self.args)

        return exception_detail

    def as_json(self):
        """
        Return `flask.jsonify` response.
        """
        response = jsonify(self.messages_dict)
        response.status_code = self.status_code
        return response


class APPException(ExceptionBase):
    """
    Provide `.status_code` and `.default_detail` properties.
    """
    code = 500
    default_detail = _(STATUS_CODE_MESSAGE.get(code))
    error_field = 'message'


class AuthException(APPException):
    """
    Token Authentication exception.
    """
    code = 401
    default_detail = _(STATUS_CODE_MESSAGE.get(code))
    error_field = 'message'


class APIException(APPException):
    """
    API exception.
    """
    code = 400
    default_detail = _(STATUS_CODE_MESSAGE.get(code))
    error_field = 'message'


class NotImplementedException(Exception):
    pass


@app.errorhandler(APPException)
def app_exception_handler(error):
    """
    Handle custom APPException in Flask.

    This function serves as a custom error handler for a specific type of exception called `APPException`. It logs the
    error using a logger named 'logger' with a critical log level and returns the error message as a JSON response.

    Parameters:
        error (APPException): The custom APPException object raised in the Flask application.

    Returns:
        dict: A JSON response containing the error message from the `APPException`.

    Example Usage:
        # Raise APPException in Flask route or view function
        raise APPException("An application-specific error occurred.")
    """
    logger.critical('[ERROR]--{}'.format(str(error)))
    return error.as_json()


@app.errorhandler(Exception)
def all_exception_handler(error):
    """
    Handle all unhandled exceptions in Flask.

    This function serves as a catch-all error handler for any unhandled exception in the Flask application. It logs the
    error using a logger named 'logger' with a critical log level. It also calls the 'utils.save_error_es_db()' function
    to save error information to Elasticsearch. Finally, it returns a JSON response with a generic error message.

    Parameters:
        error (Exception): The unhandled exception object raised in the Flask application.

    Returns:
        dict: A JSON response containing a generic error message.

    Example Usage:
        # This handler will catch any unhandled exceptions in Flask routes or view functions.
    """
    utils.save_error_es_db()
    logger.critical('[ERROR]--{}'.format(str(error)))
    response = jsonify({'message': _(STATUS_CODE_MESSAGE.get(400))})
    response.status_code = 400
    return response


@app.after_request
def after_request(response):
    """
    Post-processing of Flask responses.

    This function is a post-request hook in Flask that allows processing the response before it is sent to the client.
    If the response content type is 'application/json', it returns a custom JSON response by calling the
    'CustomResponse(response).render' method. Otherwise, it returns the original response unchanged.

    Parameters:
        response (flask.Response): The response object generated by the Flask application.

    Returns:
        flask.Response: The response object to be sent to the client, either modified or unchanged.

    Example Usage:
        # No explicit usage required, Flask will automatically call this function after each request.
    """
    if response.content_type == 'application/json':
        return CustomResponse(response).render
    return response

==> dcg_service-1.3.0.tar.gz: dcg_service-1.3.0/src/dcg_service/core/exceptions.py <==
"""
Contains override Exception class.
"""
from flask import jsonify
from flask_babel import lazy_gettext as _
from . import app, utils
from .constants import STATUS_CODE_MESSAGE
from .logger import logger
from .response import CustomResponse


class ExceptionBase(Exception):
    """
    Base exception handler
    """
    code = 500
    default_detail = _(STATUS_CODE_MESSAGE.get(code))
    error_field = 'message'

    def __init__(self, detail=None, status_code=None, raise_default=False, error_field=error_field):
        self.detail = detail or self.default_detail
        self.error_field = error_field
        if raise_default:
            self.detail = detail or self.default_detail
        self.messages = [self.detail] if isinstance(self.detail, (str, bytes)) else self.detail
        self.status_code = status_code or self.code
        super(ExceptionBase, self).__init__(detail)

    def __str__(self):
        """
        Return exception str error.
        """
        return str(self.detail)

    def get_exception_message(self, args: Exception.args):
        """
        Return Exception messages as dict.
        :param args: `Exception.args`
        :return: dict
        """
        all_exception_detail = dict()
        if isinstance(args, tuple):
            for arg in args:
                if getattr(arg, 'args', None):
                    all_exception_detail.update(self.get_exception_message(arg.args))
                elif isinstance(arg, dict):
                    all_exception_detail.update(arg)
                else:
                    all_exception_detail.update({self.error_field: str(arg) if arg else str(self.detail)})
        return all_exception_detail

    @property
    def messages_dict(self):
        """
        Return `exceptions` of type Dict.
        """
        exception_detail = self.get_exception_message(self.args)

        return exception_detail

    def as_json(self):
        """
        Return `flask.jsonify` response.
        """
        response = jsonify(self.messages_dict)
        response.status_code = self.status_code
        return response


class APPException(ExceptionBase):
    """
    Provide `.status_code` and `.default_detail` properties.
    """
    code = 500
    default_detail = _(STATUS_CODE_MESSAGE.get(code))
    error_field = 'message'


class AuthException(APPException):
    """
    Token Authentication exception.
    """
    code = 401
    default_detail = _(STATUS_CODE_MESSAGE.get(code))
    error_field = 'message'


class APIException(APPException):
    """
    API exception.
    """
    code = 400
    default_detail = _(STATUS_CODE_MESSAGE.get(code))
    error_field = 'message'


class NotImplementedException(Exception):
    pass


@app.errorhandler(APPException)
def app_exception_handler(error):
    """
    Handle custom APPException in Flask.

    This function serves as a custom error handler for a specific type of exception called `APPException`. It logs the
    error using a logger named 'logger' with a critical log level and returns the error message as a JSON response.

    Parameters:
        error (APPException): The custom APPException object raised in the Flask application.

    Returns:
        dict: A JSON response containing the error message from the `APPException`.

    Example Usage:
        # Raise APPException in Flask route or view function
        raise APPException("An application-specific error occurred.")
    """
    logger.critical('[ERROR]--{}'.format(str(error)))
    return error.as_json()


@app.errorhandler(Exception)
def all_exception_handler(error):
    """
    Handle all unhandled exceptions in Flask.

    This function serves as a catch-all error handler for any unhandled exception in the Flask application. It logs the
    error using a logger named 'logger' with a critical log level. It also calls the 'utils.save_error_es_db()' function
    to save error information to Elasticsearch. Finally, it returns a JSON response with a generic error message.

    Parameters:
        error (Exception): The unhandled exception object raised in the Flask application.

    Returns:
        dict: A JSON response containing a generic error message.

    Example Usage:
        # This handler will catch any unhandled exceptions in Flask routes or view functions.
    """
    utils.save_error_es_db()
    logger.critical('[ERROR]--{}'.format(str(error)))
    response = jsonify({'message': _(STATUS_CODE_MESSAGE.get(400)), 'error': [str(error)]})
    response.status_code = 400
    return response


@app.after_request
def after_request(response):
    """
    Post-processing of Flask responses.

    This function is a post-request hook in Flask that allows processing the response before it is sent to the client.
    If the response content type is 'application/json', it returns a custom JSON response by calling the
    'CustomResponse(response).render' method. Otherwise, it returns the original response unchanged.

    Parameters:
        response (flask.Response): The response object generated by the Flask application.

    Returns:
        flask.Response: The response object to be sent to the client, either modified or unchanged.

    Example Usage:
        # No explicit usage required, Flask will automatically call this function after each request.
    """
    if response.content_type == 'application/json':
        return CustomResponse(response).render
    return response
